@@ -1,11 +1,12 @@
 //! Evidence of malfeasance by validators (i.e. signing conflicting votes).
 
+use crate::prelude::*;
 use crate::{
     block::signed_header::SignedHeader, error::Error, serializers, vote::Power, Time, Vote,
 };
+use core::convert::{TryFrom, TryInto};
+use core::slice;
 use serde::{Deserialize, Serialize};
-use std::convert::{TryFrom, TryInto};
-use std::slice;
 use tendermint_proto::google::protobuf::Duration as RawDuration;
 use tendermint_proto::types::evidence::Sum as RawSum;
 use tendermint_proto::types::evidence::Sum;
@@ -84,7 +85,10 @@ impl TryFrom<RawDuplicateVoteEvidence> for DuplicateVoteEvidence {
                 .try_into()?,
             total_voting_power: value.total_voting_power.try_into()?,
             validator_power: value.validator_power.try_into()?,
-            timestamp: value.timestamp.ok_or_else(Error::missing_timestamp)?.into(),
+            timestamp: value
+                .timestamp
+                .ok_or_else(Error::missing_timestamp)?
+                .try_into()?,
         })
     }
 }
@@ -113,7 +117,7 @@ impl DuplicateVoteEvidence {
             vote_b,
             total_voting_power: Default::default(),
             validator_power: Default::default(),
-            timestamp: Time::now(),
+            timestamp: Time::unix_epoch(),
         })
     }
     /// Get votes
@@ -251,16 +255,16 @@ impl From<Params> for RawEvidenceParams {
     }
 }
 
-/// Duration is a wrapper around std::time::Duration
+/// Duration is a wrapper around core::time::Duration
 /// essentially, to keep the usages look cleaner
 /// i.e. you can avoid using serde annotations everywhere
-/// Todo: harmonize google::protobuf::Duration, std::time::Duration and this. Too many structs.
+/// Todo: harmonize google::protobuf::Duration, core::time::Duration and this. Too many structs.
 /// <https://github.com/informalsystems/tendermint-rs/issues/741>
 #[derive(Copy, Clone, Debug, Eq, PartialEq, Deserialize, Serialize)]
-pub struct Duration(#[serde(with = "serializers::time_duration")] pub std::time::Duration);
+pub struct Duration(#[serde(with = "serializers::time_duration")] pub core::time::Duration);
 
-impl From<Duration> for std::time::Duration {
-    fn from(d: Duration) -> std::time::Duration {
+impl From<Duration> for core::time::Duration {
+    fn from(d: Duration) -> core::time::Duration {
         d.0
     }
 }
@@ -271,7 +275,7 @@ impl TryFrom<RawDuration> for Duration {
     type Error = Error;
 
     fn try_from(value: RawDuration) -> Result<Self, Self::Error> {
-        Ok(Self(std::time::Duration::new(
+        Ok(Self(core::time::Duration::new(
             value.seconds.try_into().map_err(Error::integer_overflow)?,
             value.nanos.try_into().map_err(Error::integer_overflow)?,
         )))
