@@ -1,8 +1,9 @@
 use crate::chain;
 use crate::error::Error;
+use crate::prelude::*;
 use crate::Vote;
 use bytes::BufMut;
-use std::convert::{TryFrom, TryInto};
+use core::convert::{TryFrom, TryInto};
 use tendermint_proto::privval::SignedVoteResponse as RawSignedVoteResponse;
 use tendermint_proto::privval::{RemoteSignerError, SignVoteRequest as RawSignVoteRequest};
 use tendermint_proto::Error as ProtobufError;
@@ -96,14 +97,16 @@ mod tests {
     use crate::block::Round;
     use crate::chain::Id as ChainId;
     use crate::hash::Algorithm;
+    use crate::prelude::*;
     use crate::signature::{Signature, ED25519_SIGNATURE_SIZE};
     use crate::vote::{CanonicalVote, ValidatorIndex};
     use crate::vote::{SignVoteRequest, Type};
     use crate::Hash;
     use crate::Vote;
     use chrono::{DateTime, Utc};
-    use std::convert::TryFrom;
-    use std::str::FromStr;
+    use core::convert::TryFrom;
+    use core::str::FromStr;
+    use std::println;
     use tendermint_proto::Protobuf;
 
     #[test]
